"""PRZELOM (Breakthrough) steering method constants."""
from wisent.core.utils.config_tools.constants.for_experiments.by_method.transport._wicher import *  # noqa: F401,F403

PRZELOM_EPSILON = 1.0
OPTUNA_PRZELOM_TARGET_MODES = ("uniform", "nearest")
PRZELOM_DEFAULT_INFERENCE_K = 1.0
