"""FLORES task name registry - Part 2 (F-Z language pairs)."""
from __future__ import annotations

FLORES_TASK_NAMES_PART2 = (
        "flores_eng_Latn-taq_Tfng_prompt_2",
        "flores_eng_Latn-taq_Tfng_prompt_3",
        "flores_eng_Latn-tir_Ethi_prompt_1",
        "flores_eng_Latn-tir_Ethi_prompt_2",
        "flores_eng_Latn-tir_Ethi_prompt_3",
        "flores_eng_Latn-tsn_Latn_prompt_1",
        "flores_eng_Latn-tsn_Latn_prompt_2",
        "flores_eng_Latn-tsn_Latn_prompt_3",
        "flores_eng_Latn-tso_Latn_prompt_1",
        "flores_eng_Latn-tso_Latn_prompt_2",
        "flores_eng_Latn-tso_Latn_prompt_3",
        "flores_eng_Latn-tum_Latn_prompt_1",
        "flores_eng_Latn-tum_Latn_prompt_2",
        "flores_eng_Latn-tum_Latn_prompt_3",
        "flores_eng_Latn-twi_Latn_prompt_1",
        "flores_eng_Latn-twi_Latn_prompt_2",
        "flores_eng_Latn-twi_Latn_prompt_3",
        "flores_eng_Latn-tzm_Tfng_prompt_1",
        "flores_eng_Latn-tzm_Tfng_prompt_2",
        "flores_eng_Latn-tzm_Tfng_prompt_3",
        "flores_eng_Latn-umb_Latn_prompt_1",
        "flores_eng_Latn-umb_Latn_prompt_2",
        "flores_eng_Latn-umb_Latn_prompt_3",
        "flores_eng_Latn-wol_Latn_prompt_1",
        "flores_eng_Latn-wol_Latn_prompt_2",
        "flores_eng_Latn-wol_Latn_prompt_3",
        "flores_eng_Latn-xho_Latn_prompt_1",
        "flores_eng_Latn-xho_Latn_prompt_2",
        "flores_eng_Latn-xho_Latn_prompt_3",
        "flores_eng_Latn-yor_Latn_prompt_1",
        "flores_eng_Latn-yor_Latn_prompt_2",
        "flores_eng_Latn-yor_Latn_prompt_3",
        "flores_eng_Latn-zul_Latn_prompt_1",
        "flores_eng_Latn-zul_Latn_prompt_2",
        "flores_eng_Latn-zul_Latn_prompt_3",
        "flores_es",
        "flores_es-ca",
        "flores_es-de",
        "flores_es-en",
        "flores_es-eu",
        "flores_es-fr",
        "flores_es-gl",
        "flores_es-it",
        "flores_es-pt",
        "flores_eu",
        "flores_eu-ca",
        "flores_eu-de",
        "flores_eu-en",
        "flores_eu-es",
        "flores_eu-fr",
        "flores_eu-gl",
        "flores_eu-it",
        "flores_eu-pt",
        "flores_ewe_Latn-eng_Latn_prompt_1",
        "flores_ewe_Latn-eng_Latn_prompt_2",
        "flores_ewe_Latn-eng_Latn_prompt_3",
        "flores_fon_Latn-eng_Latn_prompt_1",
        "flores_fon_Latn-eng_Latn_prompt_2",
        "flores_fon_Latn-eng_Latn_prompt_3",
        "flores_fr-ca",
        "flores_fr-es",
        "flores_fr-eu",
        "flores_fr-gl",
        "flores_fr-pt",
        "flores_fra_Latn-eng_Latn_prompt_1",
        "flores_fra_Latn-eng_Latn_prompt_2",
        "flores_fra_Latn-eng_Latn_prompt_3",
        "flores_fuv_Latn-eng_Latn_prompt_1",
        "flores_fuv_Latn-eng_Latn_prompt_2",
        "flores_fuv_Latn-eng_Latn_prompt_3",
        "flores_gaz_Latn-eng_Latn_prompt_1",
        "flores_gaz_Latn-eng_Latn_prompt_2",
        "flores_gaz_Latn-eng_Latn_prompt_3",
        "flores_gl",
        "flores_gl-ca",
        "flores_gl-de",
        "flores_gl-en",
        "flores_gl-es",
        "flores_gl-eu",
        "flores_gl-fr",
        "flores_gl-it",
        "flores_gl-pt",
        "flores_hau_Latn-eng_Latn_prompt_1",
        "flores_hau_Latn-eng_Latn_prompt_2",
        "flores_hau_Latn-eng_Latn_prompt_3",
        "flores_ibo_Latn-eng_Latn_prompt_1",
        "flores_ibo_Latn-eng_Latn_prompt_2",
        "flores_ibo_Latn-eng_Latn_prompt_3",
        "flores_it-ca",
        "flores_it-es",
        "flores_it-eu",
        "flores_it-gl",
        "flores_it-pt",
        "flores_kab_Latn-eng_Latn_prompt_1",
        "flores_kab_Latn-eng_Latn_prompt_2",
        "flores_kab_Latn-eng_Latn_prompt_3",
        "flores_kam_Latn-eng_Latn_prompt_1",
        "flores_kam_Latn-eng_Latn_prompt_2",
        "flores_kam_Latn-eng_Latn_prompt_3",
        "flores_kbp_Latn-eng_Latn_prompt_1",
        "flores_kbp_Latn-eng_Latn_prompt_2",
        "flores_kbp_Latn-eng_Latn_prompt_3",
        "flores_kea_Latn-eng_Latn_prompt_1",
        "flores_kea_Latn-eng_Latn_prompt_2",
        "flores_kea_Latn-eng_Latn_prompt_3",
        "flores_kik_Latn-eng_Latn_prompt_1",
        "flores_kik_Latn-eng_Latn_prompt_2",
        "flores_kik_Latn-eng_Latn_prompt_3",
        "flores_kin_Latn-eng_Latn_prompt_1",
        "flores_kin_Latn-eng_Latn_prompt_2",
        "flores_kin_Latn-eng_Latn_prompt_3",
        "flores_kmb_Latn-eng_Latn_prompt_1",
        "flores_kmb_Latn-eng_Latn_prompt_2",
        "flores_kmb_Latn-eng_Latn_prompt_3",
        "flores_knc_Arab-eng_Latn_prompt_1",
        "flores_knc_Arab-eng_Latn_prompt_2",
        "flores_knc_Arab-eng_Latn_prompt_3",
        "flores_knc_Latn-eng_Latn_prompt_1",
        "flores_knc_Latn-eng_Latn_prompt_2",
        "flores_knc_Latn-eng_Latn_prompt_3",
        "flores_kon_Latn-eng_Latn_prompt_1",
        "flores_kon_Latn-eng_Latn_prompt_2",
        "flores_kon_Latn-eng_Latn_prompt_3",
        "flores_lin_Latn-eng_Latn_prompt_1",
        "flores_lin_Latn-eng_Latn_prompt_2",
        "flores_lin_Latn-eng_Latn_prompt_3",
        "flores_lua_Latn-eng_Latn_prompt_1",
        "flores_lua_Latn-eng_Latn_prompt_2",
        "flores_lua_Latn-eng_Latn_prompt_3",
        "flores_lug_Latn-eng_Latn_prompt_1",
        "flores_lug_Latn-eng_Latn_prompt_2",
        "flores_lug_Latn-eng_Latn_prompt_3",
        "flores_luo_Latn-eng_Latn_prompt_1",
        "flores_luo_Latn-eng_Latn_prompt_2",
        "flores_luo_Latn-eng_Latn_prompt_3",
        "flores_mos_Latn-eng_Latn_prompt_1",
        "flores_mos_Latn-eng_Latn_prompt_2",
        "flores_mos_Latn-eng_Latn_prompt_3",
        "flores_nso_Latn-eng_Latn_prompt_1",
        "flores_nso_Latn-eng_Latn_prompt_2",
        "flores_nso_Latn-eng_Latn_prompt_3",
        "flores_nus_Latn-eng_Latn_prompt_1",
        "flores_nus_Latn-eng_Latn_prompt_2",
        "flores_nus_Latn-eng_Latn_prompt_3",
        "flores_nya_Latn-eng_Latn_prompt_1",
        "flores_nya_Latn-eng_Latn_prompt_2",
        "flores_nya_Latn-eng_Latn_prompt_3",
        "flores_plt_Latn-eng_Latn_prompt_1",
        "flores_plt_Latn-eng_Latn_prompt_2",
        "flores_plt_Latn-eng_Latn_prompt_3",
        "flores_pt",
        "flores_pt-ca",
        "flores_pt-de",
        "flores_pt-en",
        "flores_pt-es",
        "flores_pt-eu",
        "flores_pt-fr",
        "flores_pt-gl",
        "flores_pt-it",
        "flores_run_Latn-eng_Latn_prompt_1",
        "flores_run_Latn-eng_Latn_prompt_2",
        "flores_run_Latn-eng_Latn_prompt_3",
        "flores_sag_Latn-eng_Latn_prompt_1",
        "flores_sag_Latn-eng_Latn_prompt_2",
        "flores_sag_Latn-eng_Latn_prompt_3",
        "flores_sna_Latn-eng_Latn_prompt_1",
        "flores_sna_Latn-eng_Latn_prompt_2",
        "flores_sna_Latn-eng_Latn_prompt_3",
        "flores_som_Latn-eng_Latn_prompt_1",
        "flores_som_Latn-eng_Latn_prompt_2",
        "flores_som_Latn-eng_Latn_prompt_3",
        "flores_sot_Latn-eng_Latn_prompt_1",
        "flores_sot_Latn-eng_Latn_prompt_2",
        "flores_sot_Latn-eng_Latn_prompt_3",
        "flores_ssw_Latn-eng_Latn_prompt_1",
        "flores_ssw_Latn-eng_Latn_prompt_2",
        "flores_ssw_Latn-eng_Latn_prompt_3",
        "flores_sun_Latn-eng_Latn_prompt_1",
        "flores_sun_Latn-eng_Latn_prompt_2",
        "flores_sun_Latn-eng_Latn_prompt_3",
        "flores_swh_Latn-eng_Latn_prompt_1",
        "flores_swh_Latn-eng_Latn_prompt_2",
        "flores_swh_Latn-eng_Latn_prompt_3",
        "flores_taq_Latn-eng_Latn_prompt_1",
        "flores_taq_Latn-eng_Latn_prompt_2",
        "flores_taq_Latn-eng_Latn_prompt_3",
        "flores_taq_Tfng-eng_Latn_prompt_1",
        "flores_taq_Tfng-eng_Latn_prompt_2",
        "flores_taq_Tfng-eng_Latn_prompt_3",
        "flores_tir_Ethi-eng_Latn_prompt_1",
        "flores_tir_Ethi-eng_Latn_prompt_2",
        "flores_tir_Ethi-eng_Latn_prompt_3",
        "flores_tsn_Latn-eng_Latn_prompt_1",
        "flores_tsn_Latn-eng_Latn_prompt_2",
        "flores_tsn_Latn-eng_Latn_prompt_3",
        "flores_tso_Latn-eng_Latn_prompt_1",
        "flores_tso_Latn-eng_Latn_prompt_2",
        "flores_tso_Latn-eng_Latn_prompt_3",
        "flores_tum_Latn-eng_Latn_prompt_1",
        "flores_tum_Latn-eng_Latn_prompt_2",
        "flores_tum_Latn-eng_Latn_prompt_3",
        "flores_twi_Latn-eng_Latn_prompt_1",
        "flores_twi_Latn-eng_Latn_prompt_2",
        "flores_twi_Latn-eng_Latn_prompt_3",
        "flores_tzm_Tfng-eng_Latn_prompt_1",
        "flores_tzm_Tfng-eng_Latn_prompt_2",
        "flores_tzm_Tfng-eng_Latn_prompt_3",
        "flores_umb_Latn-eng_Latn_prompt_1",
        "flores_umb_Latn-eng_Latn_prompt_2",
        "flores_umb_Latn-eng_Latn_prompt_3",
        "flores_wol_Latn-eng_Latn_prompt_1",
        "flores_wol_Latn-eng_Latn_prompt_2",
        "flores_wol_Latn-eng_Latn_prompt_3",
        "flores_xho_Latn-eng_Latn_prompt_1",
        "flores_xho_Latn-eng_Latn_prompt_2",
        "flores_xho_Latn-eng_Latn_prompt_3",
        "flores_yor_Latn-eng_Latn_prompt_1",
        "flores_yor_Latn-eng_Latn_prompt_2",
        "flores_yor_Latn-eng_Latn_prompt_3",
        "flores_zul_Latn-eng_Latn_prompt_1",
        "flores_zul_Latn-eng_Latn_prompt_2",
        "flores_zul_Latn-eng_Latn_prompt_3",
        "trasnlation_all_flores",
        "trasnlation_dr_en_flores",
        "trasnlation_dr_fr_flores",
        "trasnlation_dr_msa_flores",
        "trasnlation_en_dr_flores",
        "trasnlation_fr_dr_flores",
        "trasnlation_msa_dr_flores",
    )
